@@ -279,6 +279,70 @@ def get_label_n(y, y_pred, n=None):
 
     return y_pred
 
+def get_intersection(lst1, lst2):
+    """get the overlapping between two lists
+
+    Parameters
+    ----------
+    li1 : list or numpy array
+        Input list 1.
+
+    li2 : list or numpy array
+        Input list 2.
+
+    Returns
+    -------
+    difference : list
+        The overlapping between li1 and li2.
+    """
+    return list(set(lst1) & set(lst2))
+
+
+def get_list_diff(li1, li2):
+    """get the elements in li1 but not li2. li1-li2
+
+    Parameters
+    ----------
+    li1 : list or numpy array
+        Input list 1.
+
+    li2 : list or numpy array
+        Input list 2.
+
+    Returns
+    -------
+    difference : list
+        The difference between li1 and li2.
+    """
+    # if isinstance(li1, (np.ndarray, np.generic)):
+    #     li1 = li1.tolist()
+    # if isinstance(li2, (np.ndarray, np.generic)):
+    #     li1 = li1.tolist()
+
+    return (list(set(li1) - set(li2)))
+
+def get_diff_elements(li1, li2):
+    """get the elements in li1 but not li2, and vice versa
+
+    Parameters
+    ----------
+    li1 : list or numpy array
+        Input list 1.
+
+    li2 : list or numpy array
+        Input list 2.
+
+    Returns
+    -------
+    difference : list
+        The difference between li1 and li2.
+    """
+    # if isinstance(li1, (np.ndarray, np.generic)):
+    #     li1 = li1.tolist()
+    # if isinstance(li2, (np.ndarray, np.generic)):
+    #     li1 = li1.tolist()
+
+    return (list(set(li1) - set(li2)) + list(set(li2) - set(li1)))
 
 def argmaxn(value_list, n, order='desc'):
     """Return the index of top n elements in the list
